Available on crate feature
client only.Expand description
A2A client module.
Transport— transport-agnostic interface for all A2A protocol operationsClient— concrete client wrapping aTransportwithCallInterceptorsupportJsonRpcTransport— default HTTP/JSON-RPC + SSE transport- [
GrpcTransport] — gRPC transport (requiresgrpcfeature)
Structs
- Call
Meta - Case-insensitive metadata map carried through interceptor chains.
- Client
- A2A protocol client.
- Client
Config - Configuration options for
Clientbehavior. - Json
RpcTransport - JSON-RPC 2.0 transport for the A2A protocol.
- Passthrough
Interceptor - No-op interceptor for embedding in custom implementations.
- Request
- Transport-agnostic outgoing request that interceptors can observe and modify.
- Response
- Transport-agnostic response that interceptors can observe and modify.
- Static
Call Meta Injector - A
CallInterceptorthat attaches static metadata to all outgoing requests. - Transport
Config - Configuration for creating a
JsonRpcTransport.
Statics
- CALL_
META - Per-request metadata propagated from interceptors to the transport layer.
Traits
- Call
Interceptor - Middleware for intercepting client calls.
- Transport
- Transport-agnostic interface for all A2A protocol operations.
Functions
Type Aliases
- Event
Stream - A boxed stream of protocol
Events for streaming responses.